Title1  'BES02G3.sas   1997-9-3,  2001-2-12, 2001-3-5     Y.Takahashi  ' ;
Title2  '<<< BE / Confidence Limit vs. population BE >>> ' ;

Title3  '========  Data Set  ========== ' ;
data  W01 ;
    NEX      = 100 ;               /* Number of Iteration */
    seed     = 970903 ;            /* change the seed like 0 */
    NSAMP    = 10 ;                /* Total subject number */
    LMEAN    = log10(100) ;            /* mean of AUC   */
    LMEAN_R  = log10(100) ;            /* mean of AUC   */
    LS1      = log10(120) - LMEAN ;    /* Inter Subject */
    LS2      = log10(115) - LMEAN ;    /* Intra Subject */

    NDRUG     = 2 ;
    do  EX = 1 to NEX ;
      do  SUBJ = 1 to NSAMP ;
        LSD1 = LS1*rannor(SEED) ;
        do  DRUG = 1 to NDRUG ;
          if  DRUG=1  then  LM = LMEAN ;
                      else  LM = LMEAN_R ;
          TIME = DRUG ;
          if  (SUBJ>NSAMP/2)  then  if DRUG=1 then TIME=2 ;
                                              else TIME=1 ;
          LSD2 = LS2*rannor(SEED) ;
          LAUC = LM + LSD1 + LSD2 ;
          AUC  = 10**LAUC ;
          output ;
       end ;
     end ;
   end ;

proc print  data=W01  ;
    where  EX = 1 ;
run ;

Title3  '======== Confidence Limit ========== ' ;
proc  mixed  data=W01  noitprint  noprofile  noclprint ;
    class    DRUG  TIME  SUBJ ;
    model    LAUC =  DRUG TIME ;
    random   SUBJ ;
    lsmeans  DRUG / cl diff=control('1')  alpha=0.10 ;
    make     'fitting'   out=fit1      noprint ;
    make     'covparms'  out=cov1      noprint ;
    make     'tests'     out=test1     noprint ;
    make     'lsmeans'   out=LSMEAN1   noprint ;
    make     'diffs'     out=DIFF1     noprint ;
    by       EX ;

data  M1 ;
    set LSMEAN1 ;
    if  DRUG = '1'  then  output  ;
    keep   EX  _LSMEAN_ ;
run ;

data  D1 ;
    set   DIFF1 ;
    drop  DRUG _DRUG ;
run ;

data  J1 ;
    merge  M1 D1  ;
    P_LOW1 = 10**(_LSMEAN_ + _LOWER_) / 10**_LSMEAN_ * 100.0 ;
    P_UPP1 = 10**(_LSMEAN_ + _UPPER_) / 10**_LSMEAN_ * 100.0 ;
    by     EX     ;
    if P_LOW1 <= 80 or P_UPP1 >= 125  then JUDGE1 = 1 ;
                                      else JUDGE1 = 0 ;
proc  print  data=J1 ;
    where  EX <= 40 ;
    var     EX     _LSMEAN_  _DIFF_    _SE_    _ALPHA_
           _PT_    _LOWER_   _UPPER_    P_LOW1  P_UPP1  JUDGE1 ;

    format  _LSMEAN_   _DIFF_  _SE_     _LOWER_   _UPPER_   6.3 ;
    format  _T_        _PT_     P_LOW1   P_UPP1             6.3 ;
    format  P_LOW1      P_UPP1                              6.1 ;
run ;

proc  freq  data=J1 ;
    table  JUDGE1 ;
run ;


Title3  '======== Population BE  ========== ' ;
proc  mixed  data=W01  noclprint  noitprint noprofile  ;
    class    DRUG TIME  SUBJ ;
    model    AUC =DRUG TIME ;
    random   SUBJ ;
    lsmeans  DRUG / cl diff=control('1')  alpha=0.10 ;
    make     'fitting'     out=fit1      noprint ;
    make     'covparms'    out=cov1      noprint ;
    make     'tests'       out=test1     noprint ;
    make     'lsmeans'     out=LSMEAN2   noprint ;
    make     'diffs'       out=DIFF2     noprint ;
    by       EX ;

data  M2 ;
    set   LSMEAN2 ;
    if    DRUG = '1'  then  output  ;
    keep  EX  _LSMEAN_ ;
run ;
proc print  data=DIFF2 ; run ;
data  D2 ;
    set   DIFF2 ;
    drop  DRUG _DRUG ;
run ;

data  J2 ;
    merge  M2  D2  ;
    PERCENT= _DIFF_ / _LSMEAN_ * 100.0 ;
    DELTA  = _LSMEAN_ * 0.20 ;
    LAMDA  = DELTA / _SE_ ;
    T0     = tinv(1-_ALPHA_/2, _DF_, 0) ;
    Q1     = probt(-T0, _DF_, LAMDA) ;
    Q2     = 1 - probt( T0, _DF_, LAMDA) ;
    POWER  = Q1 + Q2 ;
    P_LOW2 = (_LSMEAN_ + _LOWER_) / _LSMEAN_ * 100.0 ;
    P_UPP2 = (_LSMEAN_ + _UPPER_) / _LSMEAN_ * 100.0 ;

    if  abs(PERCENT) < 20.0    then  J_PER   = 0 ;  else J_PER   = 1 ;
    if  _PT_         > 0.10    then  J_P     = 0 ;  else J_P     = 1 ;
    if  POWER        > 0.80    then  J_POWER = 0 ;  else J_POWER = 1 ;
    if  P_LOW2 >= 80 and P_UPP2 <= 120
                               then  J_RANGE = 0 ;  else J_RANGE = 1 ;
    JUDGE2 = J_PER + J_P + J_POWER ;
    if  JUDGE2 >= 2 then  JUDGE2 = 1 ;
    if  J_PER   = 0  and
        J_POWER = 0  and
        J_P     = 1       then   JUDGE2 = J_RANGE ;
    by     EX  ;
run ;

proc  print  data=J2 ;
    where  EX <= 40 ;
    var     EX       _LSMEAN_  _DIFF_     _SE_       _ALPHA_
            PERCENT  _PT_     POWER    DELTA    P_LOW2   P_UPP2
            J_PER    J_P     J_POWER  J_RANGE  JUDGE2 ;
    format  _LSMEAN_   DELTA  _DIFF_  _SE_   PERCENT  _LOWER_   _UPPER_   6.2;
    format  LAMDA    6.2;
    format  _T_  _PT_   POWER  6.3 ;
    format  P_LOW2   P_UPP2 6.1 ;
run ;

proc  tabulate  data=J2  format=5.0 ;
    class  J_PER    J_P   J_POWER  J_RANGE  JUDGE2 ;
    table  J_PER*J_P*J_POWER all,  J_RANGE  JUDGE2 all / rts=25 ;

run ;


Title3  '====== Power Method vs Confidence Limit =======' ;
data  J3 ;
    merge   J1 J2 ;
    if  JUDGE1 = JUDGE2   then  JUDEG=' ' ;  else  JUDGE='X' ;
    by      EX ;

proc  freq  data=J3 ;
    table   JUDGE1*JUDGE2 ;
run ;

proc  print data=J3 ;
    where   JUDGE='X' ;
    var     EX   P_LOW1  P_UPP1  JUDGE1
                 P_LOW2  P_UPP2  JUDGE2   JUDGE ;
    format  P_LOW1  P_UPP1 6.1 ;
    format  P_LOW2  P_UPP2 6.1 ;

run ;


options  ps=50  ls=66 ;

proc  timeplot  data=J3 ;
    id      EX  JUDGE1  JUDGE2  JUDGE  ;
    plot    P_LOW1='<'  P_UPP1='>'
          / npp overlay  hiloc ref=80 100 120 125
            axis=70 to 140  by 2 ;

run ;
